@@ -3,8 +3,6 @@
 // Use is subject to license terms.
 //
 
-use kube::Resource;
-
 use super::*;
 
 pub trait ClusterRoleBindingExt: super::ResourceExt {
@@ -15,11 +13,7 @@ pub trait ClusterRoleBindingExt: super::ResourceExt {
 impl ClusterRoleBindingExt for rbacv1::ClusterRoleBinding {
     fn new(name: impl ToString, cluster_role: &rbacv1::ClusterRole) -> Self {
         let metadata = Self::metadata(name);
-        let role_ref = rbacv1::RoleRef {
-            api_group: rbacv1::ClusterRole::group(&()).to_string(),
-            kind: rbacv1::ClusterRole::kind(&()).to_string(),
-            name: cluster_role.name(),
-        };
+        let role_ref = rbacv1::RoleRef::new(cluster_role);
         Self {
             metadata,
             role_ref,
